@@ -303,7 +303,7 @@ int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* respon
             parser_type = (gchar*)xmlGetProp(node, BAD_CAST "type");
             tmp = (gchar*)xmlNodeGetContent(node);
 
-            if(http_code < 300){
+            if(http_code < 300 || (http_code == 400 && g_strcmp0(parser_type, PARSER_JSON) == 0)){
                 if (g_strcmp0(parser_type, PARSER_JSON) == 0) {
                     json_parser(inner_req, pr, data, 0, &resp_str);
                     g_free(data);
@@ -977,9 +977,9 @@ xmlXPathObject* xpath(gchar* req, xmlDocPtr doc)
 
 	Obj = xmlXPathEvalExpression(BAD_CAST req, Ctx);
 
-	msa_debug("fb_xpath: end");
 
         xmlXPathFreeContext(Ctx);
+	msa_debug("fb_xpath: end");
 
 	return Obj;
 
