@@ -1,9 +1,8 @@
 /*
- * driver.h -  driver facebook of MSA program
+ * driver.h -  MySocials driver
  * This file is part of MSA program.
  *
- * Copyright (C) 2009-2010 - Sergey Zakharov
- * Copyright (C) 2010 - Pavel Shiryaev
+ * Copyright (C) 2009, 2010, 2011 - MySocials team
  *
  * MSA program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,32 +22,11 @@
 #ifndef _DRIVER_H_
 #define _DRIVER_H_
 
-#define UAGENT "Facebook Agent 1.0"
 #define PAGE_SIZE 20
-#define PREFIX "fb"
 #define MAX_COUNTER 200
 #define MID_SIZE 100
 #define URL_SIZE 1024
 
-/*functions*/
-#define GET_LIST_FRIENDS "updateListFriends"
-#define SEND_MY_PROFILE "setProfile"
-#define GET_MY_PROFILE "getProfile"
-#define UPDATE_PROFILE "updateProfile"
-#define GET_SETTINGS "getSettings"
-#define SET_SETTINGS "setSettings"
-#define SEND_MESSAGE "sendMessage"
-#define SEND_WALL_MESSAGE "sendWallMessage"
-#define GET_BINARY_DATA "getBinaryData"
-#define CAPTCHA_MESSAGE "captchaMessage"
-#define DELETE_FRIEND "deleteFriend"
-#define DELETE_MESSAGE "deleteMessage"
-
-#define PARAMS "Params"
-#define ERROR "error"
-#define CLASS "class"
-#define FUNCTION "function"
-
 #include <unistd.h>
 #include <libxml/encoding.h>
 #include <libxml/xmlwriter.h>
@@ -73,13 +51,35 @@
 #include <curl/easy.h>
 #include <glib/gprintf.h>
 
-#include "facebook.h"
+/* get system proxy from gconf (linux) */
+#include <gconf/gconf-client.h>
+
+#include "mysocials_driver.h"
+#include "driver_config.h"
 #include "profile.h"
+#include "parser.h"
+#include "dbus_functions.h"
+
+#define XPATH_TAG_REQUEST "//Request"
+#define XPATH_TAG_RESPONSE "//Response"
+#define XPATH_TAG_NOTERROR "//Response[@function!='errorMessage']"
+#define XPATH_TAG_ERROR "//Response[@function='errorMessage']"
+#define XPATH_TAG_ERROR_CODE "//Response[@function='errorMessage']/Params/string[@name='code']"
+
+#define PARSER_JSON "json"
+#define PARSER_SETTINGS "settings"
+#define PARSER_EMPTY "empty"
+#define PARSER_DOWNLOAD "download"
+#define PARSER_TEXT "text"
+#define PARSER_WEBAUTH "webauth"
 
-#define REQ "request.xml"
-#define AUTH "auth.xml"
 #define UTF8 "utf-8"
 #define CP1251 "cp1251"
+#define PARAMS "Params"
+#define ERROR "error"
+#define CLASS "class"
+#define FUNCTION "function"
+
 #define STRING "string"
 #define IMG "img"
 #define BOOLEAN "boolean"
@@ -88,6 +88,19 @@
 #define LOGIN "login"
 #define PASSWORD "password"
 
+#define ERROR_RESPONSE "<Response class='systemMessages' function='errorMessage'>\
+<Params>\
+<string name=\"moduleName\">%s</string>\
+<string name=\"code\">%s</string>\
+<string name=\"text\">%s</string>\
+<string name=\"comment\">%s</string>\
+</Params></Response>"
+
+/* get system proxy from gconf (linux) */
+#define GCONF_PROXY_HOST "/system/http_proxy/host"
+#define GCONF_PROXY_PORT "/system/http_proxy/port"
+#define GCONF_PROXY_USE "/system/http_proxy/use_http_proxy"
+
 gchar *info_proxy;
 gint info_port;
 
@@ -103,27 +116,27 @@ struct UpFile {
     gchar *name;
     gchar *file_path;
     gchar *file_name;
+    gchar **params;
 };
 
 void upfile_remove(struct UpFile *file);
 void* myrealloc(void* ptr, size_t size);
 int authorize(struct ProfileData *cp);
 int initialization(struct ProfileData *cp);
-int fb_req(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info);
+int request(xmlDocPtr reqXml, xmlDocPtr* doc, const struct msa_module* info);
 xmlChar* get_req_class(xmlDocPtr reqXml);
-gchar* get_req_function(xmlDocPtr reqXml);
+xmlChar* get_req_function(xmlDocPtr reqXml);
 int http_get(const char* url, const char* proxy, const int port, char** header, gchar** body, int* data_size);
-int http_upload_file(const char* url, const char* proxy, const int port, char** header, gchar** body, struct UpFile *file);
-int http_post(const char* url, const char* proxy, const int port, char* post_data, char** header, char** body, struct curl_slist** cookies);
-int get_settings(xmlDocPtr doc, const struct ProfileData *cp);
-int set_settings(xmlDocPtr reqXml, struct ProfileData *cp);
-int info_message(char* code, xmlDocPtr doc, char* message, int type);
+int http_upload_file(const char* url, const char* proxy, const int port, char** header, gchar** body, struct ProfileData *cp, struct UpFile *file);
+int http_post(const char* url, const char* proxy, const int port, char* post_data, char** header, char** body, int* data_size);
+void error_message(gchar* code, xmlDocPtr *doc, gchar* message, gchar *comment);
 xmlXPathObject* xpath(char* req, xmlDocPtr doc);
 xmlNodePtr xpath_get_node(char* path, xmlDocPtr doc);
 
-int parse_auth(struct ProfileData *pr, char *back_url);
 xmlDocPtr apply_parser(xmlDocPtr request, gchar* parser, struct ProfileData *pr);
 int process_request(struct ProfileData *pr, xmlDocPtr request, xmlDocPtr* response);
 int process_inner_request(struct ProfileData *pr, xmlDocPtr inner_req);
 int save_file (xmlDocPtr reqXml, char* data, int data_size);
+gchar* call_webauth(gchar* url, struct ProfileData *cp);
+
 #endif
