@@ -1,9 +1,8 @@
 /*
- * parser.c -  parser for driver facebook of MSA program
+ * parser.c -  parser for MySocials driver
  * This file is part of MSA program
  *
- * Copyright (C) 2009-2010 - Sergey Zakharov
- * Copyright (C) 2010 - Pavel Shiryaev
+ * Copyright (C) 2009, 2010, 2011 - MySocials team
  *
  * MSA program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,16 +27,19 @@
  * @param json - data in json format
  * @return 0 - on success, 1 other
  */
-int parse_upload(char* json, gchar **response)
+#ifndef NOT_USE_DEFAULT_JSON_PARSER
+int json_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
 {
     struct json_object *buf = NULL;
     gchar* resp_str = NULL;
     gchar* tmp_str = NULL;
     char *key; struct json_object *val; struct lh_entry *entry;
     char *ekey; struct json_object *eval; struct lh_entry *eentry;
-    
-    if(json != NULL) {
-        buf = json_tokener_parse(json);
+
+    if(data != NULL) {
+        g_debug("In json format:");
+        g_debug(data);
+        buf = json_tokener_parse(data);
         if(buf != NULL) {
             if (is_error(buf)){
                 *response = NULL;
@@ -73,11 +75,85 @@ int parse_upload(char* json, gchar **response)
             g_free(tmp_str);
             *response = resp_str;
             json_object_put(buf);
+        g_debug("In xml format:");
+        g_debug(*response);
             return 0;
          } 
-                
+
     }
     *response = NULL;
     return 1;
 }
+#endif
+
+#ifndef NOT_USE_DEFAULT_SETTINGS_PARSER
+int settings_parser(xmlDocPtr inner_req, struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    if(profile_update(cp, inner_req) == 0)
+        *response = g_strdup(MSG_INFO);
+    else
+        *response = g_strdup(MSG_SETTINGS_SAVED_ERROR);
+    msa_debug("settings_parser: END");
+    return 0;
+}
+#endif
+
+#ifndef NOT_USE_DEFAULT_EMPTY_PARSER
+int empty_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    *response = g_strdup("<response></response>");
+    return 0;
+}
+#endif
+
+#ifndef NOT_USE_DEFAULT_DOWNLOAD_PARSER
+int download_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    xmlNodePtr node = NULL;
+    gchar* path = NULL;
+
+    node = xpath_get_node("//*/Params/string[@name='path']", inner_req);
+    if (node == NULL){
+        *response = g_strdup(MSG_FILE_SAVE_ERROR);
+        return 1;
+    }
+    path = (gchar *)xmlNodeGetContent(node);
+    msa_debug("try save file to \"%s\"", path);
+    if (path != NULL)
+    {
+        if(g_file_set_contents(path, data, data_size, NULL)){
+            msa_debug("write to file");
+            *response = g_strdup(MSG_INFO);
+            g_free(path);
+            return 0;
+        }
+    } 
+    *response = g_strdup(MSG_FILE_SAVE_ERROR);
+    g_free(path);
+    return 1;
+}
+#endif
+
+#ifndef NOT_USE_DEFAULT_TEXT_PARSER
+int text_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    *response = g_strdup(data);
+    return 0;
+}
+#endif
+
+#ifndef NOT_USE_DEFAULT_WEBAUTH_PARSER
+int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    *response = g_strdup(data);
+    return 0;
+}
+#endif
+
+#ifndef NOT_USE_DEFAULT_PROCESS_URL
+void process_url(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    *response = g_strdup(data);
+}
+#endif
 
